@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * gtkchem3dviewer.c 
  *
- * Copyright (C) 2003-2004
+ * Copyright (C) 2003-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -16,20 +16,22 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
-#include <mol.h>
-#undef PACKAGE
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef VERSION
+#ifndef HAS_OPENBABEL_2
+#	include <mol.h>
+#	undef PACKAGE
+#	undef PACKAGE_BUGREPORT
+#	undef PACKAGE_NAME
+#	undef PACKAGE_STRING
+#	undef PACKAGE_TARNAME
+#	undef PACKAGE_VERSION
+#	undef VERSION
+#endif
 #include "config.h"
 #include "gtkchem3dviewer.h"
 #include "matrix.h"
@@ -47,6 +49,10 @@
 #include <libintl.h>
 #include <locale.h>
 #define _(String) gettext(String)
+#ifdef HAS_OPENBABEL_2
+#	include <mol.h>
+#	include <obconversion.h>
+#endif
 
 /* Attribute list for gtkglarea widget. Specifies a
      list of Boolean attributes and enum/integer
@@ -108,7 +114,9 @@ static void gtk_chem3d_viewer_set_property(GObject *object, guint property_id,
 static void gtk_chem3d_viewer_get_property(GObject *object, guint property_id,
 						GValue *value, GParamSpec *pspec);
 
+#ifndef HAS_OPENBABEL_2
 OBExtensionTable et;
+#endif
 
 static bool on_init(GtkWidget* widget, GtkChem3DViewer *viewer) 
 {
@@ -429,15 +437,23 @@ void gtk_chem3d_viewer_set_uri (GtkChem3DViewer * viewer, gchar *uri)
 
 void gtk_chem3d_viewer_set_data(GtkChem3DViewer * viewer, const gchar *data, const gchar* mime_type)
 {
-		istringstream is(data);
-		viewer->priv->Mol.SetInputType(et.MIMEToType((char*)mime_type));
-		OBFileFormat fileFormat;
-		char *old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
-		setlocale(LC_NUMERIC, "C");
-		fileFormat.ReadMolecule(is, viewer->priv->Mol);
-		setlocale(LC_NUMERIC, old_num_locale);
-		if (viewer->priv->Init) gtk_chem3d_viewer_update(viewer);
-		g_free(old_num_locale);
+	istringstream is(data);
+	viewer->priv->Mol.Clear ();
+	char *old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
+	setlocale(LC_NUMERIC, "C");
+#ifdef HAS_OPENBABEL_2
+	OBConversion Conv;
+	OBFormat* pInFormat = Conv.FormatFromMIME (mime_type);
+	Conv.SetInAndOutFormats (pInFormat, pInFormat);
+	Conv.Read (&viewer->priv->Mol, &is);
+#else
+	viewer->priv->Mol.SetInputType(et.MIMEToType((char*)mime_type));
+	OBFileFormat fileFormat;
+	fileFormat.ReadMolecule(is, viewer->priv->Mol);
+#endif
+	setlocale(LC_NUMERIC, old_num_locale);
+	if (viewer->priv->Init) gtk_chem3d_viewer_update(viewer);
+	g_free(old_num_locale);
 }
 
 void gtk_chem3d_viewer_update(GtkChem3DViewer *viewer)
